Module: SitemapGenerator
- Defined in:
- lib/sitemap_generator.rb,
lib/sitemap_generator/builder.rb,
lib/sitemap_generator/railtie.rb,
lib/sitemap_generator/link_set.rb,
lib/sitemap_generator/templates.rb,
lib/sitemap_generator/utilities.rb,
lib/sitemap_generator/application.rb,
lib/sitemap_generator/interpreter.rb,
lib/sitemap_generator/simple_namer.rb,
lib/sitemap_generator/core_ext/numeric.rb,
lib/sitemap_generator/sitemap_location.rb,
lib/sitemap_generator/adapters/s3_adapter.rb,
lib/sitemap_generator/builder/sitemap_url.rb,
lib/sitemap_generator/adapters/fog_adapter.rb,
lib/sitemap_generator/builder/sitemap_file.rb,
lib/sitemap_generator/core_ext/big_decimal.rb,
lib/sitemap_generator/adapters/file_adapter.rb,
lib/sitemap_generator/adapters/wave_adapter.rb,
lib/sitemap_generator/helpers/number_helper.rb,
lib/sitemap_generator/adapters/aws_sdk_adapter.rb,
lib/sitemap_generator/builder/sitemap_index_url.rb,
lib/sitemap_generator/builder/sitemap_index_file.rb,
lib/sitemap_generator/adapters/active_storage_adapter.rb,
lib/sitemap_generator/adapters/google_storage_adapter.rb
Overview
Define our own class rather than modify the global class
Defined Under Namespace
Modules: Builder, Helpers, Utilities Classes: ActiveStorageAdapter, Application, AwsSdkAdapter, BigDecimal, FileAdapter, FogAdapter, GoogleStorageAdapter, Interpreter, LinkSet, Numeric, Railtie, S3Adapter, SimpleNamer, SitemapError, SitemapFinalizedError, SitemapFullError, SitemapIndexLocation, SitemapLocation, Templates, WaveAdapter
Class Attribute Summary collapse
-
.app ⇒ Object
Returns the value of attribute app.
-
.root ⇒ Object
Returns the value of attribute root.
-
.templates ⇒ Object
Returns the value of attribute templates.
-
.verbose ⇒ Object
Global default for the verbose setting.
-
.yield_sitemap ⇒ Object
writeonly
Sets the attribute yield_sitemap.
Class Method Summary collapse
-
.yield_sitemap? ⇒ Boolean
Returns true if we should yield the sitemap instance to the block, false otherwise.
Class Attribute Details
.app ⇒ Object
Returns the value of attribute app.
72 73 74 |
# File 'lib/sitemap_generator.rb', line 72 def app @app end |
.root ⇒ Object
Returns the value of attribute root.
72 73 74 |
# File 'lib/sitemap_generator.rb', line 72 def root @root end |
.templates ⇒ Object
Returns the value of attribute templates.
72 73 74 |
# File 'lib/sitemap_generator.rb', line 72 def templates @templates end |
.verbose ⇒ Object
Global default for the verbose setting.
78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/sitemap_generator.rb', line 78 def self.verbose if @verbose.nil? @verbose = if SitemapGenerator::Utilities.truthy?(ENV['VERBOSE']) true elsif SitemapGenerator::Utilities.falsy?(ENV['VERBOSE']) false end else @verbose end end |
.yield_sitemap=(value) ⇒ Object (writeonly)
Sets the attribute yield_sitemap
73 74 75 |
# File 'lib/sitemap_generator.rb', line 73 def yield_sitemap=(value) @yield_sitemap = value end |
Class Method Details
.yield_sitemap? ⇒ Boolean
Returns true if we should yield the sitemap instance to the block, false otherwise.
92 93 94 |
# File 'lib/sitemap_generator.rb', line 92 def self.yield_sitemap? !!@yield_sitemap end |