Class: SitemapGenerator::Builder::SitemapUrl

Inherits:
Hash
  • Object
show all
Defined in:
lib/sitemap_generator/builder/sitemap_url.rb

Overview

A Hash-like class for holding information about a sitemap URL and generating an XML element suitable for sitemaps.

Direct Known Subclasses

SitemapIndexUrl

Instance Method Summary collapse

Constructor Details

#initialize(path, options = {}) ⇒ SitemapUrl

Return a new instance with options configured on it.

Arguments

  • sitemap - a Sitemap instance, or
  • path, options - a path string and options hash

Options

Requires a host to be set. If passing a sitemap, the sitemap must have a default_host configured. If calling with a path and options, you must include the :host option.

  • host
  • priority
  • changefreq
  • lastmod
  • images
  • +video+/+videos+
  • news
  • mobile
  • +alternate+/+alternates+
  • pagemap


33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/sitemap_generator/builder/sitemap_url.rb', line 33

def initialize(path, options = {}) # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/MethodLength, Metrics/PerceivedComplexity
  super()
  options = SitemapGenerator::Utilities.symbolize_keys(options)
  if (sitemap = path.is_a?(SitemapGenerator::Builder::SitemapFile) && path)
    SitemapGenerator::Utilities.reverse_merge!(
      options,
      host: sitemap.location.host,
      lastmod: sitemap.lastmod
    )
    path = sitemap.location.path_in_public
  end

  SitemapGenerator::Utilities.assert_valid_keys(
    options,
    :priority, :changefreq, :lastmod, :expires, :host,
    :images, :video, :news, :videos, :mobile,
    :alternate, :alternates, :pagemap
  )
  SitemapGenerator::Utilities.reverse_merge!(
    options,
    priority: 0.5,
    changefreq: 'weekly',
    lastmod: Time.now,
    images: [],
    news: {},
    videos: [],
    mobile: false,
    alternates: []
  )
  raise 'Cannot generate a url without a host' unless SitemapGenerator::Utilities.present?(options[:host])

  if (video = options.delete(:video))
    options[:videos] = video.is_a?(Array) ? options[:videos].concat(video) : options[:videos] << video
  end
  if (alternate = options.delete(:alternate))
    options[:alternates] =
      alternate.is_a?(Array) ? options[:alternates].concat(alternate) : options[:alternates] << alternate
  end

  path = path.to_s.sub(%r{^/}, '')
  loc  = path.empty? ? options[:host] : "#{options[:host].to_s.sub(%r{/$}, '')}/#{path}"
  merge!(
    priority: options[:priority],
    changefreq: options[:changefreq],
    lastmod: options[:lastmod],
    expires: options[:expires],
    host: options[:host],
    loc: loc,
    images: prepare_images(options[:images], options[:host]),
    news: prepare_news(options[:news]),
    videos: options[:videos],
    mobile: options[:mobile],
    alternates: options[:alternates],
    pagemap: options[:pagemap]
  )
end

Instance Method Details

#news?Boolean

Returns:

  • (Boolean)


197
198
199
# File 'lib/sitemap_generator/builder/sitemap_url.rb', line 197

def news?
  SitemapGenerator::Utilities.present?(self[:news])
end

#to_xml(builder = nil) ⇒ Object

Return the URL as XML



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sitemap_generator/builder/sitemap_url.rb', line 91

def to_xml(builder = nil) # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/MethodLength, Metrics/PerceivedComplexity
  builder = ::Builder::XmlMarkup.new if builder.nil?
  builder.url do # rubocop:disable Metrics/BlockLength
    builder.loc        self[:loc]
    builder.lastmod    w3c_date(self[:lastmod])      if self[:lastmod]
    builder.expires    w3c_date(self[:expires])      if self[:expires]
    builder.changefreq self[:changefreq].to_s        if self[:changefreq]
    builder.priority   format_float(self[:priority]) if self[:priority]

    unless SitemapGenerator::Utilities.blank?(self[:news])
      news_data = self[:news]
      builder.news :news do
        builder.news :publication do
          builder.news :name, news_data[:publication_name].to_s if news_data[:publication_name]
          builder.news :language, news_data[:publication_language].to_s if news_data[:publication_language]
        end

        builder.news :access, news_data[:access].to_s if news_data[:access]
        builder.news :genres, news_data[:genres].to_s if news_data[:genres]
        builder.news :publication_date, w3c_date(news_data[:publication_date]) if news_data[:publication_date]
        builder.news :title, news_data[:title].to_s if news_data[:title]
        builder.news :keywords, news_data[:keywords].to_s if news_data[:keywords]
        builder.news :stock_tickers, news_data[:stock_tickers].to_s if news_data[:stock_tickers]
      end
    end

    self[:images].each do |image|
      builder.image :image do
        builder.image :loc, image[:loc]
        builder.image :caption, image[:caption].to_s             if image[:caption]
        builder.image :geo_location, image[:geo_location].to_s   if image[:geo_location]
        builder.image :title, image[:title].to_s                 if image[:title]
        builder.image :license, image[:license].to_s             if image[:license]
      end
    end

    self[:videos].each do |video| # rubocop:disable Metrics/BlockLength
      builder.video :video do # rubocop:disable Metrics/BlockLength
        builder.video :thumbnail_loc, video[:thumbnail_loc].to_s
        builder.video :title, video[:title].to_s
        builder.video :description, video[:description].to_s
        builder.video :content_loc, video[:content_loc].to_s if video[:content_loc]
        if video[:player_loc]
          loc_attributes = { allow_embed: yes_or_no_with_default(video[:allow_embed], true) }
          if SitemapGenerator::Utilities.present?(video[:autoplay])
            loc_attributes[:autoplay] = video[:autoplay].to_s
          end
          builder.video :player_loc, video[:player_loc].to_s, loc_attributes
        end
        builder.video :duration, video[:duration].to_s if video[:duration]
        builder.video :expiration_date, w3c_date(video[:expiration_date]) if video[:expiration_date]
        builder.video :rating, format_float(video[:rating]) if video[:rating]
        builder.video :view_count, video[:view_count].to_s if video[:view_count]
        builder.video :publication_date, w3c_date(video[:publication_date]) if video[:publication_date]
        video[:tags]&.each { |tag| builder.video :tag, tag.to_s }
        builder.video :tag, video[:tag].to_s                           if video[:tag]
        builder.video :category, video[:category].to_s                 if video[:category]
        if video.key?(:family_friendly)
          builder.video :family_friendly,
                        yes_or_no_with_default(video[:family_friendly], true)
        end
        if video[:gallery_loc]
          builder.video :gallery_loc, video[:gallery_loc].to_s,
                        title: video[:gallery_title].to_s
        end
        if SitemapGenerator::Utilities.present?(video[:price])
          builder.video :price, video[:price].to_s, prepare_video_price_attribs(video)
        end
        if video[:uploader]
          builder.video :uploader, video[:uploader].to_s,
                        video[:uploader_info] ? { info: video[:uploader_info].to_s } : {}
        end
        builder.video :live, yes_or_no_with_default(video[:live], true) if video.key?(:live)
        if video.key?(:requires_subscription)
          builder.video :requires_subscription,
                        yes_or_no_with_default(video[:requires_subscription],
                                               true)
        end
      end
    end

    self[:alternates].each do |alternate|
      rel = alternate[:nofollow] ? 'alternate nofollow' : 'alternate'
      attributes = { rel: rel, href: alternate[:href].to_s }
      attributes[:hreflang] = alternate[:lang].to_s if SitemapGenerator::Utilities.present?(alternate[:lang])
      attributes[:media] = alternate[:media].to_s if SitemapGenerator::Utilities.present?(alternate[:media])
      builder.xhtml :link, attributes
    end

    builder.mobile :mobile unless SitemapGenerator::Utilities.blank?(self[:mobile])

    unless SitemapGenerator::Utilities.blank?(self[:pagemap])
      builder.pagemap :PageMap do
        SitemapGenerator::Utilities.as_array(self[:pagemap][:dataobjects]).each do |dataobject|
          builder.pagemap :DataObject, type: dataobject[:type].to_s, id: dataobject[:id].to_s do
            SitemapGenerator::Utilities.as_array(dataobject[:attributes]).each do |attribute|
              builder.pagemap :Attribute, attribute[:value].to_s, name: attribute[:name].to_s
            end
          end
        end
      end
    end
  end
  builder << '' # Force to string
end